module Dspace
  module Resources
    class AuthenticationResource < ResourceKit::Resource

      resources do

        default_handler(400) { raise InvalidTokenError, 'Invalid access token.' }
        default_handler(403) { raise InvalidCredentialsError, 'Wrong Dspace credentials.' }
        default_handler(401) { raise NotAuthorizedError, 'This request requires authentication' }
        default_handler(404) { raise NotFoundError, 'The specified object doesn\'t exist' }
        default_handler(405) { raise MethodNotAllowedError, 'Wrong request method (GET,POST,PUT,DELETE) or wrong data format (JSON/XML)' }
        default_handler(415) { raise UnsupportedMediaTypeError, 'Missing "Content-Type: application/json" or "Content-Type: application/xml" request header' }
        default_handler(500) { raise ServerError, 'Likely a SQLException, IOException, more details in the logs' }
        default_handler { |response| raise StandardError, "#{response.inspect}" }

        action :login, 'POST /rest/login' do
          body { |email, password| JSON.generate({email: email, password: password}) }
          handler(200, 201) { |response| access_token = response.body }
        end

        action :logout, 'POST /rest/logout' do
          body { |object| JSON.generate(object.to_h) }
          handler(200, 201, 203, 204) { |response| true }
        end

      end

    end
  end
end
